==> servicecatalog-model-5.10.2-sources.jar: io/fabric8/servicecatalog/api/model/ServiceInstanceStatusBuilder.java <==
package io.fabric8.servicecatalog.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ServiceInstanceStatusBuilder extends io.fabric8.servicecatalog.api.model.ServiceInstanceStatusFluentImpl<io.fabric8.servicecatalog.api.model.ServiceInstanceStatusBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.servicecatalog.api.model.ServiceInstanceStatus,io.fabric8.servicecatalog.api.model.ServiceInstanceStatusBuilder>{
  public ServiceInstanceStatusBuilder() {
    this(false);
  }
  public ServiceInstanceStatusBuilder(java.lang.Boolean validationEnabled) {
    this(new ServiceInstanceStatus(), validationEnabled);
  }
  public ServiceInstanceStatusBuilder(io.fabric8.servicecatalog.api.model.ServiceInstanceStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public ServiceInstanceStatusBuilder(io.fabric8.servicecatalog.api.model.ServiceInstanceStatusFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ServiceInstanceStatus(), validationEnabled);
  }
  public ServiceInstanceStatusBuilder(io.fabric8.servicecatalog.api.model.ServiceInstanceStatusFluent<?> fluent,io.fabric8.servicecatalog.api.model.ServiceInstanceStatus instance) {
    this(fluent, instance, false);
  }
  public ServiceInstanceStatusBuilder(io.fabric8.servicecatalog.api.model.ServiceInstanceStatusFluent<?> fluent,io.fabric8.servicecatalog.api.model.ServiceInstanceStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAsyncOpInProgress(instance.getAsyncOpInProgress()); 
    fluent.withConditions(instance.getConditions()); 
    fluent.withCurrentOperation(instance.getCurrentOperation()); 
    fluent.withDashboardURL(instance.getDashboardURL()); 
    fluent.withDefaultProvisionParameters(instance.getDefaultProvisionParameters()); 
    fluent.withDeprovisionStatus(instance.getDeprovisionStatus()); 
    fluent.withExternalProperties(instance.getExternalProperties()); 
    fluent.withInProgressProperties(instance.getInProgressProperties()); 
    fluent.withLastOperation(instance.getLastOperation()); 
    fluent.withObservedGeneration(instance.getObservedGeneration()); 
    fluent.withOperationStartTime(instance.getOperationStartTime()); 
    fluent.withOrphanMitigationInProgress(instance.getOrphanMitigationInProgress()); 
    fluent.withProvisionStatus(instance.getProvisionStatus()); 
    fluent.withReconciledGeneration(instance.getReconciledGeneration()); 
    this.validationEnabled = validationEnabled; 
  }
  public ServiceInstanceStatusBuilder(io.fabric8.servicecatalog.api.model.ServiceInstanceStatus instance) {
    this(instance,false);
  }
  public ServiceInstanceStatusBuilder(io.fabric8.servicecatalog.api.model.ServiceInstanceStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAsyncOpInProgress(instance.getAsyncOpInProgress()); 
    this.withConditions(instance.getConditions()); 
    this.withCurrentOperation(instance.getCurrentOperation()); 
    this.withDashboardURL(instance.getDashboardURL()); 
    this.withDefaultProvisionParameters(instance.getDefaultProvisionParameters()); 
    this.withDeprovisionStatus(instance.getDeprovisionStatus()); 
    this.withExternalProperties(instance.getExternalProperties()); 
    this.withInProgressProperties(instance.getInProgressProperties()); 
    this.withLastOperation(instance.getLastOperation()); 
    this.withObservedGeneration(instance.getObservedGeneration()); 
    this.withOperationStartTime(instance.getOperationStartTime()); 
    this.withOrphanMitigationInProgress(instance.getOrphanMitigationInProgress()); 
    this.withProvisionStatus(instance.getProvisionStatus()); 
    this.withReconciledGeneration(instance.getReconciledGeneration()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.servicecatalog.api.model.ServiceInstanceStatusFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.servicecatalog.api.model.ServiceInstanceStatus build() {
    ServiceInstanceStatus buildable = new ServiceInstanceStatus(fluent.getAsyncOpInProgress(),fluent.getConditions(),fluent.getCurrentOperation(),fluent.getDashboardURL(),fluent.getDefaultProvisionParameters(),fluent.getDeprovisionStatus(),fluent.getExternalProperties(),fluent.getInProgressProperties(),fluent.getLastOperation(),fluent.getObservedGeneration(),fluent.getOperationStartTime(),fluent.getOrphanMitigationInProgress(),fluent.getProvisionStatus(),fluent.getReconciledGeneration());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ServiceInstanceStatusBuilder that = (ServiceInstanceStatusBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> servicecatalog-model-6.6.2-sources.jar: io/fabric8/servicecatalog/api/model/ServiceInstanceStatusBuilder.java <==
package io.fabric8.servicecatalog.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ServiceInstanceStatusBuilder extends ServiceInstanceStatusFluentImpl<ServiceInstanceStatusBuilder> implements VisitableBuilder<ServiceInstanceStatus,ServiceInstanceStatusBuilder>{
  public ServiceInstanceStatusBuilder() {
    this(false);
  }
  public ServiceInstanceStatusBuilder(Boolean validationEnabled) {
    this(new ServiceInstanceStatus(), validationEnabled);
  }
  public ServiceInstanceStatusBuilder(ServiceInstanceStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public ServiceInstanceStatusBuilder(ServiceInstanceStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ServiceInstanceStatus(), validationEnabled);
  }
  public ServiceInstanceStatusBuilder(ServiceInstanceStatusFluent<?> fluent,ServiceInstanceStatus instance) {
    this(fluent, instance, false);
  }
  public ServiceInstanceStatusBuilder(ServiceInstanceStatusFluent<?> fluent,ServiceInstanceStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAsyncOpInProgress(instance.getAsyncOpInProgress()); 
    fluent.withConditions(instance.getConditions()); 
    fluent.withCurrentOperation(instance.getCurrentOperation()); 
    fluent.withDashboardURL(instance.getDashboardURL()); 
    fluent.withDefaultProvisionParameters(instance.getDefaultProvisionParameters()); 
    fluent.withDeprovisionStatus(instance.getDeprovisionStatus()); 
    fluent.withExternalProperties(instance.getExternalProperties()); 
    fluent.withInProgressProperties(instance.getInProgressProperties()); 
    fluent.withLastOperation(instance.getLastOperation()); 
    fluent.withObservedGeneration(instance.getObservedGeneration()); 
    fluent.withOperationStartTime(instance.getOperationStartTime()); 
    fluent.withOrphanMitigationInProgress(instance.getOrphanMitigationInProgress()); 
    fluent.withProvisionStatus(instance.getProvisionStatus()); 
    fluent.withReconciledGeneration(instance.getReconciledGeneration()); 
    this.validationEnabled = validationEnabled; 
  }
  public ServiceInstanceStatusBuilder(ServiceInstanceStatus instance) {
    this(instance,false);
  }
  public ServiceInstanceStatusBuilder(ServiceInstanceStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withAsyncOpInProgress(instance.getAsyncOpInProgress()); 
    this.withConditions(instance.getConditions()); 
    this.withCurrentOperation(instance.getCurrentOperation()); 
    this.withDashboardURL(instance.getDashboardURL()); 
    this.withDefaultProvisionParameters(instance.getDefaultProvisionParameters()); 
    this.withDeprovisionStatus(instance.getDeprovisionStatus()); 
    this.withExternalProperties(instance.getExternalProperties()); 
    this.withInProgressProperties(instance.getInProgressProperties()); 
    this.withLastOperation(instance.getLastOperation()); 
    this.withObservedGeneration(instance.getObservedGeneration()); 
    this.withOperationStartTime(instance.getOperationStartTime()); 
    this.withOrphanMitigationInProgress(instance.getOrphanMitigationInProgress()); 
    this.withProvisionStatus(instance.getProvisionStatus()); 
    this.withReconciledGeneration(instance.getReconciledGeneration()); 
    this.validationEnabled = validationEnabled; 
  }
  ServiceInstanceStatusFluent<?> fluent;
  Boolean validationEnabled;
  public ServiceInstanceStatus build() {
    ServiceInstanceStatus buildable = new ServiceInstanceStatus(fluent.getAsyncOpInProgress(),fluent.getConditions(),fluent.getCurrentOperation(),fluent.getDashboardURL(),fluent.getDefaultProvisionParameters(),fluent.getDeprovisionStatus(),fluent.getExternalProperties(),fluent.getInProgressProperties(),fluent.getLastOperation(),fluent.getObservedGeneration(),fluent.getOperationStartTime(),fluent.getOrphanMitigationInProgress(),fluent.getProvisionStatus(),fluent.getReconciledGeneration());
    return buildable;
  }
  
}
